Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

### Earth-Ref Sample Help Window

- Some of the data you entered in er_sites.txt is now propagated into er_samples.txt. Check that this information is correct.

- Check sample class (under the header sample_class).
  If you need to change it because site class is different from sample class: use controlled vocabularies from `sample class controlled vocabularies
  To edit values for the entire column, click the column header. Class can take multiple values in the form of a colon-delimited list, i.e. Extrusive:Igneous. You may use the drop-down menus to add as many values as needed in these columns.` .
- Check sample lithology (under the header sample_lithology).
  If you need to change it because site lithology is different from sample lithology: use controlled vocabularies from `sample lithology controlled vocabularies`. If you can't find any appropriate definition use: Not Specified.
  To edit values for the entire column, click the column header. Lithology can take multiple values in the form of a colon-delimited list, i.e. Silicate-Sandstone:Silicate-Mud. You may use the drop-down menus to add as many values as needed in these columns.
- Check sample type (under the header sample_type).
  If you need to change it because site type is different from sample type: use controlled vocabularies from `sample type controlled vocabularies`. If you can't find any appropriate definition use: Not Specified.
  To edit values for the entire column, click the column header. Type can take multiple values in the form of a colon-delimited list, i.e. Baked-Mud:Baked-Rock You may use the drop-down menus to add as many values as needed in these columns.

- To edit values for an entire column, click the column header.